#
# spec file for package sfftobmp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname sfftobmp3
Name:           sfftobmp
Version:        3.1.4
Release:        8.15
Summary:        Tool to convert Structured Fax Files (.sff) to other image formats
License:        MIT
Group:          Hardware/ISDN
URL:            https://sf.net/projects/sfftools/
Source:         %{rname}-%{version}.tar.xz
Patch0:         boost_library.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  unix2dos

%description
The CAPI interface for programming ISDN hardware expects and gives
faxes in the "Structured Fax File" (SFF) format.

SffToBmp is a converter tool, written in C++, to transform SFF files to
BMP, JPEG or multipage TIFF format. In addition generation of PBM files
(Portable Bitmap) is also possible which can be transformed into nearby
all other graphics formats using the PBMPLUS tools that are included in
almost every Linux distribution nowadays.

%prep
%autosetup -p1 -n %{rname}-%{version}

chmod a+x configure
dos2unix -c mac src/output.h

%build
# This needs updating time and again
export CPPFLAGS="-DBOOST_FILESYSTEM_VERSION=3"

touch INSTALL NEWS README AUTHORS ChangeLog COPYING
autoreconf --force --install
%configure

#
# There will be a warning,
# 	main.cpp:303:16: warning: deleting object of abstract class
#	type 'COutputFilter' which has non-virtual destructor will
#	cause undefined behaviour [-Wdelete-non-virtual-dtor]
# which is - so far - however harmless, because there are no destructors
# *at all* in the derived classes.
#
%make_build

%install
%make_install
install -d %{buildroot}/%{_defaultdocdir}/sfftobmp/getopt
install -m 644 doc/getopt/* %{buildroot}/%{_defaultdocdir}/sfftobmp/getopt
rm -rf doc/getopt
install -m 644 doc/* %{buildroot}/%{_defaultdocdir}/sfftobmp

%files
%{_bindir}/sfftobmp
%doc %{_defaultdocdir}/sfftobmp

%changelog
* Tue Mar  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Replace sanitize_source.sh with a _service file
- Don't use an insecure download URL (boo#1182933)
- Spec cleanup
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing libboost_system-devel dependency.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
- add sanitize_source.sh to spec file as a source.
* Wed Jan 25 2017 adam.majer@suse.de
- boost_library.patch: link with boost that does not provide
  the *-mt.so library symlinks.
* Sun Jun 16 2013 jengelh@inai.de
- Set BOOST_FILESYSTEM=3 in .spec file to be able to build with
  boost-1.53
- Remove sfftobmp-linking.patch (unused)
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 3.1.4
  * treat files with empty pages correctly
- Remove sfftobmp-gcc43.diff (merged upstream),
  sfftobmp-codecleanup.diff (resolved differently upstream),
  sfftobmp-linking.patch (resolved upstream)
* Fri Dec  2 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Aug 29 2011 crrodriguez@opensuse.org
- link with boost_system too, fix build
* Mon Mar 21 2011 pth@suse.de
- Fix class member initialisation to quite the compiler.
- Cast vars to the type matching the printf format.
* Mon Mar 21 2011 pth@suse.de
- Compile with BOOST_FILESYSTEM_VERSION=2 to force the v2 API.
* Thu Feb 26 2009 crrodriguez@suse.de
- extend GCC 4.3 patch to over gcc  4.4 as well
* Thu Feb 21 2008 kkeil@suse.de
- fix permissions of doc files
* Thu Oct 11 2007 kkeil@suse.de
- fixes for GCC 4.3
* Mon Oct  8 2007 kkeil@suse.de
- update to current 3.1.1
  * set the "DateTime" field within TIFF files with the UTC value
    of the input file's mtime
* Mon Mar  5 2007 kkeil@suse.de
- update to current 3.1 version
  V3.0:
  * changed commandline options, now includes multi-file processing
  * made keeping the date possible for linux, too
  * fixed decoder bug which did not decode a full line
  (Kudos to Eckhard Rueggeberg)
  * fixed extended MH codes (wrong bitorder)
  V3.1:
  * changed message output from stderr to stdout except errors
  * added -quiet switch
  * some fixes from debian package
  * some big endian fixes
  * allowed up to 2048 bytes "fuzz" at the beginning of the file
* Fri May 26 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Mar 30 2005 kkeil@suse.de
- a dword is always 32 bit, also on 64 bit OS (#75254)
* Thu Jun 12 2003 kkeil@suse.de
- fix filelist
* Tue Feb  4 2003 ghillie@suse.de
- updated to 2.2 (includes writing TIFFs to stdout now)
- removed sfftobmp-stdout.diff as it has been included by upstream
  maintainer
* Mon Dec 16 2002 gernot@hillier.de
- first package
